@@ -7,8 +7,10 @@ import (
 	"fmt"
 	"io"
 	"os"
+	"sort"
 	"strings"
 	"testing"
+	"time"
 
 	"github.com/mikefarah/yq/v4/test"
 	"gopkg.in/op/go-logging.v1"
@@ -24,11 +26,15 @@ type expressionScenario struct {
 	expression            string
 	expected              []string
 	skipDoc               bool
+	expectedError         string
 	dontFormatInputForDoc bool // dont format input doc for documentation generation
 }
 
 func TestMain(m *testing.M) {
 	logging.SetLevel(logging.ERROR, "")
+	Now = func() time.Time {
+		return time.Date(2021, time.May, 19, 1, 2, 3, 4, time.UTC)
+	}
 	code := m.Run()
 	os.Exit(code)
 }
@@ -93,6 +99,11 @@ func testScenario(t *testing.T, s *expressionScenario) {
 
 	context, err := NewDataTreeNavigator().GetMatchingNodes(Context{MatchingNodes: inputs}, node)
 
+	if s.expectedError != "" {
+		test.AssertResultComplexWithContext(t, s.expectedError, err.Error(), fmt.Sprintf("desc: %v\nexp: %v\ndoc: %v", s.description, s.expression, s.document))
+		return
+	}
+
 	if err != nil {
 		t.Error(fmt.Errorf("%w: %v", err, s.expression))
 		return
@@ -237,7 +248,14 @@ func documentInput(w *bufio.Writer, s expressionScenario) (string, string) {
 
 	envCommand := ""
 
-	for name, value := range s.environmentVariables {
+	envKeys := make([]string, 0, len(s.environmentVariables))
+	for k := range s.environmentVariables {
+		envKeys = append(envKeys, k)
+	}
+	sort.Strings(envKeys)
+
+	for _, name := range envKeys {
+		value := s.environmentVariables[name]
 		if envCommand == "" {
 			envCommand = fmt.Sprintf("%v=\"%v\" ", name, value)
 		} else {
