@@ -2,87 +2,13 @@ package yqlib
 
 import (
 	"bufio"
-	"bytes"
 	"fmt"
-	"strings"
 	"testing"
 
 	"github.com/mikefarah/yq/v4/test"
-	yaml "gopkg.in/yaml.v3"
 )
 
-func decodeXml(t *testing.T, s formatScenario) *CandidateNode {
-	decoder := NewXmlDecoder("+", "+content")
-
-	decoder.Init(strings.NewReader(s.input))
-
-	node := &yaml.Node{}
-	err := decoder.Decode(node)
-	if err != nil {
-		t.Error(err, "fail to decode", s.input)
-	}
-
-	expression := s.expression
-	if expression == "" {
-		expression = "."
-	}
-
-	exp, err := getExpressionParser().ParseExpression(expression)
-
-	if err != nil {
-		t.Error(err)
-		return nil
-	}
-
-	candidateNode := CandidateNode{Node: node}
-
-	context, err := NewDataTreeNavigator().GetMatchingNodes(Context{MatchingNodes: candidateNode.AsList()}, exp)
-
-	if err != nil {
-		t.Error(err)
-		return nil
-	}
-
-	return context.MatchingNodes.Front().Value.(*CandidateNode)
-}
-
-func processXmlScenario(s formatScenario) string {
-	var output bytes.Buffer
-	writer := bufio.NewWriter(&output)
-
-	var encoder = NewXmlEncoder(2, "+", "+content")
-
-	var decoder = NewYamlDecoder()
-	if s.scenarioType == "roundtrip" {
-		decoder = NewXmlDecoder("+", "+content")
-	}
-
-	inputs, err := readDocuments(strings.NewReader(s.input), "sample.yml", 0, decoder)
-	if err != nil {
-		panic(err)
-	}
-	node := inputs.Front().Value.(*CandidateNode).Node
-	err = encoder.Encode(writer, node)
-	if err != nil {
-		panic(err)
-	}
-	writer.Flush()
-
-	return output.String()
-}
-
-type formatScenario struct {
-	input          string
-	indent         int
-	expression     string
-	expected       string
-	description    string
-	subdescription string
-	skipDoc        bool
-	scenarioType   string
-}
-
-var inputXmlWithComments = `
+var inputXMLWithComments = `
 <!-- before cat -->
 <cat>
 	<!-- in cat before -->
@@ -100,7 +26,7 @@ for x --></x>
 </cat>
 <!-- after cat -->
 `
-var inputXmlWithCommentsWithSubChild = `
+var inputXMLWithCommentsWithSubChild = `
 <!-- before cat -->
 <cat>
 	<!-- in cat before -->
@@ -119,7 +45,7 @@ for x --></x>
 <!-- after cat -->
 `
 
-var expectedDecodeYamlWithSubChild = `D0, P[], (doc)::# before cat
+var expectedDecodeYamlWithSubChild = `# before cat
 cat:
     # in cat before
     x: "3" # multi
@@ -139,7 +65,7 @@ cat:
 # after cat
 `
 
-var inputXmlWithCommentsWithArray = `
+var inputXMLWithCommentsWithArray = `
 <!-- before cat -->
 <cat>
 	<!-- in cat before -->
@@ -159,7 +85,7 @@ for x --></x>
 <!-- after cat -->
 `
 
-var expectedDecodeYamlWithArray = `D0, P[], (doc)::# before cat
+var expectedDecodeYamlWithArray = `# before cat
 cat:
     # in cat before
     x: "3" # multi
@@ -183,7 +109,7 @@ cat:
 # after cat
 `
 
-var expectedDecodeYamlWithComments = `D0, P[], (doc)::# before cat
+var expectedDecodeYamlWithComments = `# before cat
 cat:
     # in cat before
     x: "3" # multi
@@ -200,7 +126,7 @@ cat:
 # after cat
 `
 
-var expectedRoundtripXmlWithComments = `<!-- before cat --><cat><!-- in cat before -->
+var expectedRoundtripXMLWithComments = `<!-- before cat --><cat><!-- in cat before -->
   <x>3<!-- multi
 line comment 
 for x --></x><!-- before y -->
@@ -221,7 +147,7 @@ cat: # inline_cat
 # below_cat
 `
 
-var expectedXmlWithComments = `<!-- above_cat inline_cat --><cat><!-- above_array inline_array -->
+var expectedXMLWithComments = `<!-- above_cat inline_cat --><cat><!-- above_array inline_array -->
   <array>val1<!-- inline_val1 --></array>
   <array><!-- above_val2 -->val2<!-- inline_val2 --></array>
 </cat><!-- below_cat -->
@@ -232,51 +158,79 @@ var xmlScenarios = []formatScenario{
 		description:    "Parse xml: simple",
 		subdescription: "Notice how all the values are strings, see the next example on how you can fix that.",
 		input:          "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<cat>\n  <says>meow</says>\n  <legs>4</legs>\n  <cute>true</cute>\n</cat>",
-		expected:       "D0, P[], (doc)::cat:\n    says: meow\n    legs: \"4\"\n    cute: \"true\"\n",
+		expected:       "cat:\n    says: meow\n    legs: \"4\"\n    cute: \"true\"\n",
 	},
 	{
 		description:    "Parse xml: number",
 		subdescription: "All values are assumed to be strings when parsing XML, but you can use the `from_yaml` operator on all the strings values to autoparse into the correct type.",
 		input:          "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<cat>\n  <says>meow</says>\n  <legs>4</legs>\n  <cute>true</cute>\n</cat>",
 		expression:     " (.. | select(tag == \"!!str\")) |= from_yaml",
-		expected:       "D0, P[], ()::cat:\n    says: meow\n    legs: 4\n    cute: true\n",
+		expected:       "cat:\n    says: meow\n    legs: 4\n    cute: true\n",
 	},
 	{
 		description:    "Parse xml: array",
 		subdescription: "Consecutive nodes with identical xml names are assumed to be arrays.",
 		input:          "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<animal>cat</animal>\n<animal>goat</animal>",
-		expected:       "D0, P[], (doc)::animal:\n    - cat\n    - goat\n",
+		expected:       "animal:\n    - cat\n    - goat\n",
 	},
 	{
 		description:    "Parse xml: attributes",
 		subdescription: "Attributes are converted to fields, with the default attribute prefix '+'. Use '--xml-attribute-prefix` to set your own.",
 		input:          "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<cat legs=\"4\">\n  <legs>7</legs>\n</cat>",
-		expected:       "D0, P[], (doc)::cat:\n    +legs: \"4\"\n    legs: \"7\"\n",
+		expected:       "cat:\n    +legs: \"4\"\n    legs: \"7\"\n",
 	},
 	{
 		description:    "Parse xml: attributes with content",
 		subdescription: "Content is added as a field, using the default content name of `+content`. Use `--xml-content-name` to set your own.",
 		input:          "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<cat legs=\"4\">meow</cat>",
-		expected:       "D0, P[], (doc)::cat:\n    +content: meow\n    +legs: \"4\"\n",
+		expected:       "cat:\n    +content: meow\n    +legs: \"4\"\n",
 	},
 	{
 		description:    "Parse xml: with comments",
 		subdescription: "A best attempt is made to preserve comments.",
-		input:          inputXmlWithComments,
+		input:          inputXMLWithComments,
 		expected:       expectedDecodeYamlWithComments,
 		scenarioType:   "decode",
 	},
+	{
+		description:  "Empty doc",
+		skipDoc:      true,
+		input:        "",
+		expected:     "",
+		scenarioType: "decode",
+	},
+	{
+		description:  "Empty single node",
+		skipDoc:      true,
+		input:        "<a/>",
+		expected:     "a:\n",
+		scenarioType: "decode",
+	},
+	{
+		description:  "Empty close node",
+		skipDoc:      true,
+		input:        "<a></a>",
+		expected:     "a:\n",
+		scenarioType: "decode",
+	},
+	{
+		description:  "Nested empty",
+		skipDoc:      true,
+		input:        "<a><b/></a>",
+		expected:     "a:\n    b:\n",
+		scenarioType: "decode",
+	},
 	{
 		description:  "Parse xml: with comments subchild",
 		skipDoc:      true,
-		input:        inputXmlWithCommentsWithSubChild,
+		input:        inputXMLWithCommentsWithSubChild,
 		expected:     expectedDecodeYamlWithSubChild,
 		scenarioType: "decode",
 	},
 	{
 		description:  "Parse xml: with comments array",
 		skipDoc:      true,
-		input:        inputXmlWithCommentsWithArray,
+		input:        inputXMLWithCommentsWithArray,
 		expected:     expectedDecodeYamlWithArray,
 		scenarioType: "decode",
 	},
@@ -316,44 +270,45 @@ var xmlScenarios = []formatScenario{
 		description:    "Encode xml: comments",
 		subdescription: "A best attempt is made to copy comments to xml.",
 		input:          yamlWithComments,
-		expected:       expectedXmlWithComments,
+		expected:       expectedXMLWithComments,
 		scenarioType:   "encode",
 	},
 	{
 		description:    "Round trip: with comments",
 		subdescription: "A best effort is made, but comment positions and white space are not preserved perfectly.",
-		input:          inputXmlWithComments,
-		expected:       expectedRoundtripXmlWithComments,
+		input:          inputXMLWithComments,
+		expected:       expectedRoundtripXMLWithComments,
 		scenarioType:   "roundtrip",
 	},
 }
 
-func testXmlScenario(t *testing.T, s formatScenario) {
-	if s.scenarioType == "encode" || s.scenarioType == "roundtrip" {
-		test.AssertResultWithContext(t, s.expected, processXmlScenario(s), s.description)
+func testXMLScenario(t *testing.T, s formatScenario) {
+	if s.scenarioType == "encode" {
+		test.AssertResultWithContext(t, s.expected, processFormatScenario(s, NewYamlDecoder(), NewXMLEncoder(2, "+", "+content")), s.description)
+	} else if s.scenarioType == "roundtrip" {
+		test.AssertResultWithContext(t, s.expected, processFormatScenario(s, NewXMLDecoder("+", "+content"), NewXMLEncoder(2, "+", "+content")), s.description)
 	} else {
-		var actual = resultToString(t, decodeXml(t, s))
-		test.AssertResultWithContext(t, s.expected, actual, s.description)
+		test.AssertResultWithContext(t, s.expected, processFormatScenario(s, NewXMLDecoder("+", "+content"), NewYamlEncoder(4, false, true, true)), s.description)
 	}
 }
 
-func documentXmlScenario(t *testing.T, w *bufio.Writer, i interface{}) {
+func documentXMLScenario(t *testing.T, w *bufio.Writer, i interface{}) {
 	s := i.(formatScenario)
 
 	if s.skipDoc {
 		return
 	}
 	if s.scenarioType == "encode" {
-		documentXmlEncodeScenario(w, s)
+		documentXMLEncodeScenario(w, s)
 	} else if s.scenarioType == "roundtrip" {
-		documentXmlRoundTripScenario(w, s)
+		documentXMLRoundTripScenario(w, s)
 	} else {
-		documentXmlDecodeScenario(t, w, s)
+		documentXMLDecodeScenario(w, s)
 	}
 
 }
 
-func documentXmlDecodeScenario(t *testing.T, w *bufio.Writer, s formatScenario) {
+func documentXMLDecodeScenario(w *bufio.Writer, s formatScenario) {
 	writeOrPanic(w, fmt.Sprintf("## %v\n", s.description))
 
 	if s.subdescription != "" {
@@ -372,21 +327,10 @@ func documentXmlDecodeScenario(t *testing.T, w *bufio.Writer, s formatScenario)
 	writeOrPanic(w, fmt.Sprintf("```bash\nyq -p=xml '%v' sample.xml\n```\n", expression))
 	writeOrPanic(w, "will output\n")
 
-	var output bytes.Buffer
-	printer := NewSimpleYamlPrinter(bufio.NewWriter(&output), YamlOutputFormat, true, false, 2, true)
-
-	node := decodeXml(t, s)
-
-	err := printer.PrintResults(node.AsList())
-	if err != nil {
-		t.Error(err)
-		return
-	}
-
-	writeOrPanic(w, fmt.Sprintf("```yaml\n%v```\n\n", output.String()))
+	writeOrPanic(w, fmt.Sprintf("```yaml\n%v```\n\n", processFormatScenario(s, NewXMLDecoder("+", "+content"), NewYamlEncoder(2, false, true, true))))
 }
 
-func documentXmlEncodeScenario(w *bufio.Writer, s formatScenario) {
+func documentXMLEncodeScenario(w *bufio.Writer, s formatScenario) {
 	writeOrPanic(w, fmt.Sprintf("## %v\n", s.description))
 
 	if s.subdescription != "" {
@@ -401,10 +345,10 @@ func documentXmlEncodeScenario(w *bufio.Writer, s formatScenario) {
 	writeOrPanic(w, "```bash\nyq -o=xml '.' sample.yml\n```\n")
 	writeOrPanic(w, "will output\n")
 
-	writeOrPanic(w, fmt.Sprintf("```xml\n%v```\n\n", processXmlScenario(s)))
+	writeOrPanic(w, fmt.Sprintf("```xml\n%v```\n\n", processFormatScenario(s, NewYamlDecoder(), NewXMLEncoder(2, "+", "+content"))))
 }
 
-func documentXmlRoundTripScenario(w *bufio.Writer, s formatScenario) {
+func documentXMLRoundTripScenario(w *bufio.Writer, s formatScenario) {
 	writeOrPanic(w, fmt.Sprintf("## %v\n", s.description))
 
 	if s.subdescription != "" {
@@ -419,16 +363,16 @@ func documentXmlRoundTripScenario(w *bufio.Writer, s formatScenario) {
 	writeOrPanic(w, "```bash\nyq -p=xml -o=xml '.' sample.xml\n```\n")
 	writeOrPanic(w, "will output\n")
 
-	writeOrPanic(w, fmt.Sprintf("```xml\n%v```\n\n", processXmlScenario(s)))
+	writeOrPanic(w, fmt.Sprintf("```xml\n%v```\n\n", processFormatScenario(s, NewXMLDecoder("+", "+content"), NewXMLEncoder(2, "+", "+content"))))
 }
 
-func TestXmlScenarios(t *testing.T) {
+func TestXMLScenarios(t *testing.T) {
 	for _, tt := range xmlScenarios {
-		testXmlScenario(t, tt)
+		testXMLScenario(t, tt)
 	}
 	genericScenarios := make([]interface{}, len(xmlScenarios))
 	for i, s := range xmlScenarios {
 		genericScenarios[i] = s
 	}
-	documentScenarios(t, "usage", "xml", genericScenarios, documentXmlScenario)
+	documentScenarios(t, "usage", "xml", genericScenarios, documentXMLScenario)
 }
